Non OpenStack Brick
===============================



.. image:: https://img.shields.io/pypi/v/nos_brick.svg
   :target: https://pypi.python.org/pypi/nos_brick

.. image:: https://img.shields.io/travis/akrog/nos_brick.svg
   :target: https://travis-ci.org/akrog/nos_brick

.. image:: https://readthedocs.org/projects/nos-brick/badge/?version=latest
   :target: https://nos-brick.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/nos_brick.svg
   :target: https://pypi.python.org/pypi/nos_brick

.. image:: https://pyup.io/repos/github/akrog/nos_brick/shield.svg
     :target: https://pyup.io/repos/github/akrog/nos_brick/
     :alt: Updates

.. image:: https://img.shields.io/:license-apache-blue.svg
   :target: http://www.apache.org/licenses/LICENSE-2.0


Volume discovery and local storage management lib for non OpenStack deployments


* Free software: Apache Software License 2.0
* Documentation: https://nos-brick.readthedocs.io.


Features
--------

* TODO
